@@ -3,6 +3,8 @@
 # This example is wrapped in dontrun in the Rd for files2SpectraObject
 # as it takes a bit of time, so run only at home
 
+home <- identical(Sys.info()["nodename"], "Abbott-2.local")
+if (home) {
   expect_silent( {
     options(ChemoSpecGraphics = "base")
     ed <- system.file("extdata", package = "ChemoSpec")
@@ -14,4 +16,4 @@
     sumSpectra(spec)
     plotSpectra(spec, lab.pos = 3.5, main = "Reduced Fat Potato Chip")
   })
-
+}
